The module elements
===================

.. currentmodule:: pylbm.elements

.. versionadded:: 0.2
  the geometrical elements are yet implemented in 3D.

The module elements contains all the geometrical shapes that can be used
to build the geometry.

The 2D elements are:

.. autosummary::
   :toctree: generated/
   
   Circle
   Ellipse
   Parallelogram
   Triangle

The 3D elements are:

.. autosummary::
   :toctree: generated/

   Sphere
   Ellipsoid
   Parallelepiped
   Cylinder_Circle
   Cylinder_Ellipse
   Cylinder_Triangle
  